/**
 * PIC32MX Minimal SPI master example, tested on an EasyPIC Fusion v8 with a
 * PIC32MX795F512L sending data to an EasyPIC3 with a PIC18F458
 *
 * Compiler versions tested:
 *   - MikroC PRO for PIC v6.5.0
 *   - MikroC PRO for PIC32 v3.5.0
 *
 * Example uses SPI3A as this is the only SPI port on the PIC32MX795F512L that 
 * has all the pins on the same output header.
 *
 * SPI pins:
 *   RF13 = SCK (pin 39)
 *   RF4 = SDI (pin 49)
 *   RF5 = SDO (pin 50)
 *
 * Note: 
 *  - _SPI_ACTIVE_2_IDLE in MikroC PRO for PIC32 equals _SPI_HIGH_2_LOW in
 *    MikroC PRO for PIC
 *  - in MikroC, SPI3A is named SPI4
 *  - Data sent through SPI is displayed on PORTB
 *  - PIC32 SPI is 5v tolerant so no voltage conversion is needed between a 
 *    PIC18F and a PIC32.
 *  - Data sent has been confirmed with a Saleae logic probe.
 */
unsigned short state=0;

void main() {
  //Visualise output on port B
  TRISB = 0;
  PORTB = 0;

  //NB: SPI4 = SPI3A on the chip as Mikroelektronika and Microchip use
  //    different naming schemes
  SPI4_Init_Advanced(
    _SPI_MASTER,
    _SPI_8_BIT,
    1024,
    _SPI_SS_DISABLE,
    _SPI_DATA_SAMPLE_MIDDLE,
    _SPI_CLK_IDLE_LOW,
    _SPI_ACTIVE_2_IDLE);
  
  while(1){
    SPI4_write(state);
    PORTB = state;
    state++;
    delay_ms(1000);
  }
}